You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ode.apache.org by mr...@apache.org on 2006/07/27 23:52:07 UTC

svn commit: r426260 [12/23] - in /incubator/ode/scratch/pxe-iapi: ./ axis2-examples/src/examples/DynPartner/ axis2-examples/src/examples/HelloWorld2/ axis2-examples/src/examples/MagicSession/ axis2-war/ axis2-war/src/main/webapp/WEB-INF/ axis2-war/src/...

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessAndInstanceManagementImpl.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessAndInstanceManagementImpl.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessAndInstanceManagementImpl.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessAndInstanceManagementImpl.java Thu Jul 27 14:51:14 2006
@@ -4,20 +4,20 @@
  *
  */
 
-package com.fs.pxe.bpel.engine;
+package org.apache.ode.bpel.engine;
 
-import com.fs.pxe.bpel.common.*;
-import com.fs.pxe.bpel.dao.*;
-import com.fs.pxe.bpel.evt.BpelEvent;
-import com.fs.pxe.bpel.evtproc.ActivityStateDocumentBuilder;
-import com.fs.pxe.bpel.o.OPartnerLink;
-import com.fs.pxe.bpel.o.OProcess;
-import com.fs.pxe.bpel.pmapi.*;
-import com.fs.utils.DOMUtils;
-import com.fs.utils.ISO8601DateParser;
-import com.fs.utils.msg.MessageBundle;
-import com.fs.utils.stl.CollectionsX;
-import com.fs.utils.stl.UnaryFunction;
+import org.apache.ode.bpel.common.*;
+import org.apache.ode.bpel.dao.*;
+import org.apache.ode.bpel.evt.BpelEvent;
+import org.apache.ode.bpel.evtproc.ActivityStateDocumentBuilder;
+import org.apache.ode.bpel.o.OPartnerLink;
+import org.apache.ode.bpel.o.OProcess;
+import org.apache.ode.bpel.pmapi.*;
+import org.apache.ode.utils.DOMUtils;
+import org.apache.ode.utils.ISO8601DateParser;
+import org.apache.ode.utils.msg.MessageBundle;
+import org.apache.ode.utils.stl.CollectionsX;
+import org.apache.ode.utils.stl.UnaryFunction;
 import org.apache.commons.collections.map.MultiKeyMap;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -845,7 +845,7 @@
 
 
   /**
-   * @see com.fs.pxe.bpel.pmapi.InstanceManagement#listInstances(java.lang.String)
+   * @see org.apache.ode.bpel.pmapi.InstanceManagement#listInstances(java.lang.String)
    */
   public InstanceInfoListDocument listInstances(final String query) {
     InstanceInfoListDocument ret = InstanceInfoListDocument.Factory.newInstance();

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessDDInitializer.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessDDInitializer.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessInitializer.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessInitializer.java Thu Jul 27 14:51:14 2006
@@ -1,18 +1,18 @@
-package com.fs.pxe.bpel.engine;
+package org.apache.ode.bpel.engine;
 
 import javax.xml.namespace.QName;
 
-import com.fs.pxe.bpel.dao.PartnerLinkDAO;
-import com.fs.pxe.bpel.dao.ProcessDAO;
-import com.fs.pxe.bpel.dd.TDeploymentDescriptor;
-import com.fs.pxe.bpel.dd.TRoles;
-import com.fs.pxe.bpel.iapi.BpelEngineException;
-import com.fs.pxe.bpel.iapi.EndpointReference;
-import com.fs.pxe.bpel.o.OPartnerLink;
-import com.fs.pxe.bpel.o.OProcess;
-import com.fs.utils.DOMUtils;
-import com.fs.utils.Namespaces;
-import com.fs.utils.msg.MessageBundle;
+import org.apache.ode.bpel.dao.PartnerLinkDAO;
+import org.apache.ode.bpel.dao.ProcessDAO;
+import org.apache.ode.bpel.dd.TDeploymentDescriptor;
+import org.apache.ode.bpel.dd.TRoles;
+import org.apache.ode.bpel.iapi.BpelEngineException;
+import org.apache.ode.bpel.iapi.EndpointReference;
+import org.apache.ode.bpel.o.OPartnerLink;
+import org.apache.ode.bpel.o.OProcess;
+import org.apache.ode.utils.DOMUtils;
+import org.apache.ode.utils.Namespaces;
+import org.apache.ode.utils.msg.MessageBundle;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.w3c.dom.Document;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessStatusConverter.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessStatusConverter.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ReplacementMapImpl.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ReplacementMapImpl.java Thu Jul 27 14:51:14 2006
@@ -3,11 +3,11 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.engine;
+package org.apache.ode.bpel.engine;
 
 import com.fs.jacob.soup.ReplacementMap;
-import com.fs.pxe.bpel.o.OBase;
-import com.fs.pxe.bpel.o.OProcess;
+import org.apache.ode.bpel.o.OBase;
+import org.apache.ode.bpel.o.OProcess;
 
 /**
  * A JACOB {@link ReplacementMap} implementation that eliminates unnecessary serialization

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/WorkEvent.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/WorkEvent.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/WorkEvent.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/WorkEvent.java Thu Jul 27 14:51:14 2006
@@ -1,4 +1,4 @@
-package com.fs.pxe.bpel.engine;
+package org.apache.ode.bpel.engine;
 
 import java.util.HashMap;
 import java.util.Map;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/evtproc/ActivityStateDocumentBuilder.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/evtproc/ActivityStateDocumentBuilder.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/evtproc/ActivityStateDocumentBuilder.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/evtproc/ActivityStateDocumentBuilder.java Thu Jul 27 14:51:14 2006
@@ -1,20 +1,20 @@
-package com.fs.pxe.bpel.evtproc;
+package org.apache.ode.bpel.evtproc;
 
 import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.HashMap;
 import java.util.List;
 
-import com.fs.pxe.bpel.engine.BpelEventListener;
-import com.fs.pxe.bpel.evt.ActivityEnabledEvent;
-import com.fs.pxe.bpel.evt.ActivityEvent;
-import com.fs.pxe.bpel.evt.ActivityExecEndEvent;
-import com.fs.pxe.bpel.evt.ActivityExecStartEvent;
-import com.fs.pxe.bpel.evt.BpelEvent;
-import com.fs.pxe.bpel.pmapi.*;
+import org.apache.ode.bpel.engine.BpelEventListener;
+import org.apache.ode.bpel.evt.ActivityEnabledEvent;
+import org.apache.ode.bpel.evt.ActivityEvent;
+import org.apache.ode.bpel.evt.ActivityExecEndEvent;
+import org.apache.ode.bpel.evt.ActivityExecStartEvent;
+import org.apache.ode.bpel.evt.BpelEvent;
+import org.apache.ode.bpel.pmapi.*;
 
 /**
- * Class used to generate {@link com.fs.pxe.bpel.pmapi.istate.InstanceDocument}
+ * Class used to generate {@link org.apache.ode.bpel.pmapi.istate.InstanceDocument}
  * objects.
  */
 public class ActivityStateDocumentBuilder implements BpelEventListener {

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ACTIVITY.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ACTIVITY.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ACTIVITY.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ACTIVITY.java Thu Jul 27 14:51:14 2006
@@ -3,13 +3,13 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.evt.ActivityEvent;
-import com.fs.pxe.bpel.evt.ScopeEvent;
-import com.fs.pxe.bpel.explang.EvaluationContext;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OLink;
+import org.apache.ode.bpel.evt.ActivityEvent;
+import org.apache.ode.bpel.evt.ScopeEvent;
+import org.apache.ode.bpel.explang.EvaluationContext;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OLink;
 
 import java.util.Collection;
 import java.util.Iterator;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ACTIVITYGUARD.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ACTIVITYGUARD.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ACTIVITYGUARD.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ACTIVITYGUARD.java Thu Jul 27 14:51:14 2006
@@ -3,20 +3,20 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import com.fs.jacob.ML;
 import com.fs.jacob.SynchChannel;
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.evt.ActivityEnabledEvent;
-import com.fs.pxe.bpel.evt.ActivityExecEndEvent;
-import com.fs.pxe.bpel.evt.ActivityExecStartEvent;
-import com.fs.pxe.bpel.explang.EvaluationException;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OExpression;
-import com.fs.pxe.bpel.o.OLink;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.runtime.channels.*;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.evt.ActivityEnabledEvent;
+import org.apache.ode.bpel.evt.ActivityExecEndEvent;
+import org.apache.ode.bpel.evt.ActivityExecStartEvent;
+import org.apache.ode.bpel.explang.EvaluationException;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OExpression;
+import org.apache.ode.bpel.o.OLink;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.runtime.channels.*;
 
 import java.util.*;
 
@@ -145,7 +145,7 @@
 
   /**
    * Intercepts the
-   * {@link ParentScopeChannel#completed(com.fs.pxe.bpel.runtime.channels.FaultData, java.util.Set<com.fs.pxe.bpel.runtime.CompensationHandler>)}
+   * {@link ParentScopeChannel#completed(org.apache.ode.bpel.runtime.channels.FaultData, java.util.Set<org.apache.ode.bpel.runtime.CompensationHandler>)}
    * call, to evaluate transition conditions before returning to the parent.
    */
   private class TCONDINTERCEPT extends BpelAbstraction {

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ASSIGN.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ASSIGN.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ASSIGN.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ASSIGN.java Thu Jul 27 14:51:14 2006
@@ -3,25 +3,25 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.evt.PartnerLinkModificationEvent;
-import com.fs.pxe.bpel.evt.ScopeEvent;
-import com.fs.pxe.bpel.evt.VariableModificationEvent;
-import com.fs.pxe.bpel.explang.EvaluationContext;
-import com.fs.pxe.bpel.explang.EvaluationException;
-import com.fs.pxe.bpel.o.*;
-import com.fs.pxe.bpel.o.OAssign.LValueExpression;
-import com.fs.pxe.bpel.o.OAssign.PropertyRef;
-import com.fs.pxe.bpel.o.OAssign.VariableRef;
-import com.fs.pxe.bpel.o.OMessageVarType.Part;
-import com.fs.pxe.bpel.o.OProcess.OProperty;
-import com.fs.pxe.bpel.o.OScope.Variable;
-import com.fs.pxe.bpel.runtime.channels.FaultData;
-import com.fs.utils.DOMUtils;
-import com.fs.utils.Namespaces;
-import com.fs.utils.msg.MessageBundle;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.evt.PartnerLinkModificationEvent;
+import org.apache.ode.bpel.evt.ScopeEvent;
+import org.apache.ode.bpel.evt.VariableModificationEvent;
+import org.apache.ode.bpel.explang.EvaluationContext;
+import org.apache.ode.bpel.explang.EvaluationException;
+import org.apache.ode.bpel.o.*;
+import org.apache.ode.bpel.o.OAssign.LValueExpression;
+import org.apache.ode.bpel.o.OAssign.PropertyRef;
+import org.apache.ode.bpel.o.OAssign.VariableRef;
+import org.apache.ode.bpel.o.OMessageVarType.Part;
+import org.apache.ode.bpel.o.OProcess.OProperty;
+import org.apache.ode.bpel.o.OScope.Variable;
+import org.apache.ode.bpel.runtime.channels.FaultData;
+import org.apache.ode.utils.DOMUtils;
+import org.apache.ode.utils.Namespaces;
+import org.apache.ode.utils.msg.MessageBundle;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.w3c.dom.*;
@@ -537,8 +537,8 @@
 				return _ctx.readVariable(variable, part);
 
 		}		/**
-				 * @see com.fs.pxe.bpel.explang.EvaluationContext#readMessageProperty(com.fs.pxe.bpel.o.OScope.Variable,
-				 *      com.fs.pxe.bpel.o.OProcess.OProperty)
+				 * @see org.apache.ode.bpel.explang.EvaluationContext#readMessageProperty(org.apache.ode.bpel.o.OScope.Variable,
+				 *      org.apache.ode.bpel.o.OProcess.OProperty)
 				 */
 		public String readMessageProperty(Variable variable, OProperty property)
 				throws FaultException {
@@ -546,22 +546,22 @@
 		}
 
 		/**
-		 * @see com.fs.pxe.bpel.explang.EvaluationContext#isLinkActive(com.fs.pxe.bpel.o.OLink)
+		 * @see org.apache.ode.bpel.explang.EvaluationContext#isLinkActive(org.apache.ode.bpel.o.OLink)
 		 */
 		public boolean isLinkActive(OLink olink) throws FaultException {
 			return _ctx.isLinkActive(olink);
 		}
 
 		/**
-		 * @see com.fs.pxe.bpel.explang.EvaluationContext#getRootNode()
+		 * @see org.apache.ode.bpel.explang.EvaluationContext#getRootNode()
 		 */
 		public Node getRootNode() {
 			return _rootNode;
 		}
 
 		/**
-		 * @see com.fs.pxe.bpel.explang.EvaluationContext#evaluateQuery(org.w3c.dom.Node,
-		 *      com.fs.pxe.bpel.o.OExpression)
+		 * @see org.apache.ode.bpel.explang.EvaluationContext#evaluateQuery(org.w3c.dom.Node,
+		 *      org.apache.ode.bpel.o.OExpression)
 		 */
 		public Node evaluateQuery(Node root, OExpression expr)
 				throws FaultException {
@@ -569,7 +569,7 @@
 			try {
 				return getBpelRuntimeContext().getExpLangRuntime()
 						.evaluateNode(expr, this);
-			} catch (com.fs.pxe.bpel.explang.EvaluationException e) {
+			} catch (org.apache.ode.bpel.explang.EvaluationException e) {
 				throw new InvalidProcessException("Expression Failed: " + expr,
 						e);
 			}

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ASSIGNMessages.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ASSIGNMessages.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ASSIGNMessages.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ASSIGNMessages.java Thu Jul 27 14:51:14 2006
@@ -1,7 +1,7 @@
 
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.utils.msg.MessageBundle;
+import org.apache.ode.utils.msg.MessageBundle;
 
 /**
  * Internationalization for messages related to assignment.

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ActivityInfo.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ActivityInfo.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ActivityInfo.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ActivityInfo.java Thu Jul 27 14:51:14 2006
@@ -3,11 +3,11 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.runtime.channels.ParentScopeChannel;
-import com.fs.pxe.bpel.runtime.channels.TerminationChannel;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.runtime.channels.ParentScopeChannel;
+import org.apache.ode.bpel.runtime.channels.TerminationChannel;
 
 import java.io.Serializable;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ActivityTemplateFactory.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ActivityTemplateFactory.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ActivityTemplateFactory.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ActivityTemplateFactory.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.o.*;
+import org.apache.ode.bpel.o.*;
 
 /**
  * Factory for creating activity template objects.

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/BpelAbstraction.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/BpelAbstraction.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/BpelAbstraction.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/BpelAbstraction.java Thu Jul 27 14:51:14 2006
@@ -3,16 +3,16 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import com.fs.jacob.Abstraction;
 import com.fs.jacob.vpu.JacobVPU;
-import com.fs.pxe.bpel.common.CorrelationKey;
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.o.OBase;
-import com.fs.pxe.bpel.o.OProcess;
-import com.fs.pxe.bpel.o.OVarType;
-import com.fs.pxe.bpel.runtime.channels.FaultData;
+import org.apache.ode.bpel.common.CorrelationKey;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.o.OBase;
+import org.apache.ode.bpel.o.OProcess;
+import org.apache.ode.bpel.o.OVarType;
+import org.apache.ode.bpel.runtime.channels.FaultData;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.w3c.dom.Element;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/BpelRuntimeContext.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/BpelRuntimeContext.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/BpelRuntimeContext.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/BpelRuntimeContext.java Thu Jul 27 14:51:14 2006
@@ -3,20 +3,20 @@
 * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
 *
 */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.common.CorrelationKey;
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.evt.ProcessInstanceEvent;
-import com.fs.pxe.bpel.o.OMessageVarType;
-import com.fs.pxe.bpel.o.OMessageVarType.Part;
-import com.fs.pxe.bpel.o.OPartnerLink;
-import com.fs.pxe.bpel.o.OProcess;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.runtime.channels.FaultData;
-import com.fs.pxe.bpel.runtime.channels.InvokeResponseChannel;
-import com.fs.pxe.bpel.runtime.channels.PickResponseChannel;
-import com.fs.pxe.bpel.runtime.channels.TimerResponseChannel;
+import org.apache.ode.bpel.common.CorrelationKey;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.evt.ProcessInstanceEvent;
+import org.apache.ode.bpel.o.OMessageVarType;
+import org.apache.ode.bpel.o.OMessageVarType.Part;
+import org.apache.ode.bpel.o.OPartnerLink;
+import org.apache.ode.bpel.o.OProcess;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.runtime.channels.FaultData;
+import org.apache.ode.bpel.runtime.channels.InvokeResponseChannel;
+import org.apache.ode.bpel.runtime.channels.PickResponseChannel;
+import org.apache.ode.bpel.runtime.channels.TimerResponseChannel;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/COMPENSATE.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/COMPENSATE.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/COMPENSATE.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/COMPENSATE.java Thu Jul 27 14:51:14 2006
@@ -3,12 +3,12 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import com.fs.jacob.SynchChannel;
 import com.fs.jacob.SynchML;
-import com.fs.pxe.bpel.o.OCompensate;
-import com.fs.pxe.bpel.o.OScope;
+import org.apache.ode.bpel.o.OCompensate;
+import org.apache.ode.bpel.o.OScope;
 
 
 /**

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/COMPENSATIONHANDLER_.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/COMPENSATIONHANDLER_.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/COMPENSATIONHANDLER_.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/COMPENSATIONHANDLER_.java Thu Jul 27 14:51:14 2006
@@ -3,13 +3,13 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import com.fs.jacob.SynchChannel;
-import com.fs.pxe.bpel.evt.CompensationHandlerRegistered;
-import com.fs.pxe.bpel.evt.ScopeEvent;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.runtime.channels.*;
+import org.apache.ode.bpel.evt.CompensationHandlerRegistered;
+import org.apache.ode.bpel.evt.ScopeEvent;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.runtime.channels.*;
 
 import java.util.Iterator;
 import java.util.Set;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ChildInfo.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ChildInfo.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ChildInfo.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ChildInfo.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import java.io.Serializable;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/CompensationHandler.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/CompensationHandler.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/CompensationHandler.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/CompensationHandler.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.runtime.channels.CompensationChannel;
+import org.apache.ode.bpel.runtime.channels.CompensationChannel;
 
 import java.io.Serializable;
 import java.util.Collections;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/CorrelationSetInstance.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/CorrelationSetInstance.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/CorrelationSetInstance.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/CorrelationSetInstance.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.o.OScope;
+import org.apache.ode.bpel.o.OScope;
 
 public class CorrelationSetInstance {
   public OScope.CorrelationSet declaration;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/EH_ALARM.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/EH_ALARM.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/EH_ALARM.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/EH_ALARM.java Thu Jul 27 14:51:14 2006
@@ -3,15 +3,15 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import com.fs.jacob.SynchChannel;
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.explang.EvaluationContext;
-import com.fs.pxe.bpel.explang.EvaluationException;
-import com.fs.pxe.bpel.o.OEventHandler;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.runtime.channels.*;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.explang.EvaluationContext;
+import org.apache.ode.bpel.explang.EvaluationException;
+import org.apache.ode.bpel.o.OEventHandler;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.runtime.channels.*;
 
 import java.util.Calendar;
 import java.util.HashSet;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/EH_EVENT.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/EH_EVENT.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/EH_EVENT.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/EH_EVENT.java Thu Jul 27 14:51:14 2006
@@ -3,15 +3,15 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import com.fs.jacob.ML;
 import com.fs.jacob.SynchChannel;
-import com.fs.pxe.bpel.common.CorrelationKey;
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.o.OEventHandler;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.runtime.channels.*;
+import org.apache.ode.bpel.common.CorrelationKey;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.o.OEventHandler;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.runtime.channels.*;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.w3c.dom.Element;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/EMPTY.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/EMPTY.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/EMPTY.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/EMPTY.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ExprEvaluationContextImpl.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ExprEvaluationContextImpl.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ExpressionLanguageRuntimeRegistry.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ExpressionLanguageRuntimeRegistry.java Thu Jul 27 14:51:14 2006
@@ -3,16 +3,16 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.explang.ConfigurationException;
-import com.fs.pxe.bpel.explang.EvaluationContext;
-import com.fs.pxe.bpel.explang.EvaluationException;
-import com.fs.pxe.bpel.explang.ExpressionLanguageRuntime;
-import com.fs.pxe.bpel.o.OExpression;
-import com.fs.pxe.bpel.o.OExpressionLanguage;
-import com.fs.utils.xsd.Duration;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.explang.ConfigurationException;
+import org.apache.ode.bpel.explang.EvaluationContext;
+import org.apache.ode.bpel.explang.EvaluationException;
+import org.apache.ode.bpel.explang.ExpressionLanguageRuntime;
+import org.apache.ode.bpel.o.OExpression;
+import org.apache.ode.bpel.o.OExpressionLanguage;
+import org.apache.ode.utils.xsd.Duration;
 import org.w3c.dom.Node;
 
 import java.util.Calendar;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/FLOW.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/FLOW.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/FLOW.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/FLOW.java Thu Jul 27 14:51:14 2006
@@ -3,17 +3,17 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import com.fs.jacob.ML;
 import com.fs.jacob.SynchChannel;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OFlow;
-import com.fs.pxe.bpel.o.OLink;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.runtime.channels.*;
-import com.fs.utils.stl.FilterIterator;
-import com.fs.utils.stl.MemberOfFunction;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OFlow;
+import org.apache.ode.bpel.o.OLink;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.runtime.channels.*;
+import org.apache.ode.utils.stl.FilterIterator;
+import org.apache.ode.utils.stl.MemberOfFunction;
 
 import java.util.HashSet;
 import java.util.Iterator;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/FOREACH.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/FOREACH.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/FOREACH.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/FOREACH.java Thu Jul 27 14:51:14 2006
@@ -1,17 +1,17 @@
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import com.fs.jacob.ML;
 import com.fs.jacob.SynchChannel;
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.elang.xpath10.o.OXPath10Expression;
-import com.fs.pxe.bpel.explang.EvaluationException;
-import com.fs.pxe.bpel.o.OExpression;
-import com.fs.pxe.bpel.o.OForEach;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.runtime.channels.*;
-import com.fs.utils.DOMUtils;
-import com.fs.utils.stl.FilterIterator;
-import com.fs.utils.stl.MemberOfFunction;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.elang.xpath10.o.OXPath10Expression;
+import org.apache.ode.bpel.explang.EvaluationException;
+import org.apache.ode.bpel.o.OExpression;
+import org.apache.ode.bpel.o.OForEach;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.runtime.channels.*;
+import org.apache.ode.utils.DOMUtils;
+import org.apache.ode.utils.stl.FilterIterator;
+import org.apache.ode.utils.stl.MemberOfFunction;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.w3c.dom.Document;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/INVOKE.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/INVOKE.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/INVOKE.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/INVOKE.java Thu Jul 27 14:51:14 2006
@@ -3,14 +3,14 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.o.OInvoke;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.runtime.channels.FaultData;
-import com.fs.pxe.bpel.runtime.channels.InvokeResponseChannel;
-import com.fs.pxe.bpel.runtime.channels.InvokeResponseML;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.o.OInvoke;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.runtime.channels.FaultData;
+import org.apache.ode.bpel.runtime.channels.InvokeResponseChannel;
+import org.apache.ode.bpel.runtime.channels.InvokeResponseML;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/InvalidProcessException.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/InvalidProcessException.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/InvalidProcessException.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/InvalidProcessException.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 /**
  * A run-time exception indicating that the process is invalid. This should not

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/LinkFrame.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/LinkFrame.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/LinkFrame.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/LinkFrame.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.o.OLink;
+import org.apache.ode.bpel.o.OLink;
 
 import java.io.Serializable;
 import java.util.HashMap;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/LinkInfo.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/LinkInfo.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/LinkInfo.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/LinkInfo.java Thu Jul 27 14:51:14 2006
@@ -3,10 +3,10 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.o.OLink;
-import com.fs.pxe.bpel.runtime.channels.LinkStatusChannel;
+import org.apache.ode.bpel.o.OLink;
+import org.apache.ode.bpel.runtime.channels.LinkStatusChannel;
 
 import java.io.Serializable;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ORDEREDCOMPENSATOR.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ORDEREDCOMPENSATOR.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ORDEREDCOMPENSATOR.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ORDEREDCOMPENSATOR.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import com.fs.jacob.SynchChannel;
 import com.fs.jacob.SynchML;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PICK.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PICK.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PICK.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PICK.java Thu Jul 27 14:51:14 2006
@@ -3,19 +3,19 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.common.CorrelationKey;
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.explang.EvaluationException;
-import com.fs.pxe.bpel.o.OPickReceive;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.runtime.channels.FaultData;
-import com.fs.pxe.bpel.runtime.channels.PickResponseChannel;
-import com.fs.pxe.bpel.runtime.channels.PickResponseML;
-import com.fs.pxe.bpel.runtime.channels.TerminationML;
-import com.fs.utils.xsd.Duration;
-import com.fs.utils.DOMUtils;
+import org.apache.ode.bpel.common.CorrelationKey;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.explang.EvaluationException;
+import org.apache.ode.bpel.o.OPickReceive;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.runtime.channels.FaultData;
+import org.apache.ode.bpel.runtime.channels.PickResponseChannel;
+import org.apache.ode.bpel.runtime.channels.PickResponseML;
+import org.apache.ode.bpel.runtime.channels.TerminationML;
+import org.apache.ode.utils.xsd.Duration;
+import org.apache.ode.utils.DOMUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.w3c.dom.Element;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PROCESS.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PROCESS.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PROCESS.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PROCESS.java Thu Jul 27 14:51:14 2006
@@ -3,16 +3,16 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import com.fs.jacob.SynchChannel;
-import com.fs.pxe.bpel.evt.ProcessInstanceStartedEvent;
-import com.fs.pxe.bpel.o.OProcess;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.runtime.channels.FaultData;
-import com.fs.pxe.bpel.runtime.channels.ParentScopeChannel;
-import com.fs.pxe.bpel.runtime.channels.ParentScopeML;
-import com.fs.pxe.bpel.runtime.channels.TerminationChannel;
+import org.apache.ode.bpel.evt.ProcessInstanceStartedEvent;
+import org.apache.ode.bpel.o.OProcess;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.runtime.channels.FaultData;
+import org.apache.ode.bpel.runtime.channels.ParentScopeChannel;
+import org.apache.ode.bpel.runtime.channels.ParentScopeML;
+import org.apache.ode.bpel.runtime.channels.TerminationChannel;
 
 import java.util.Set;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PartnerLinkInstance.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PartnerLinkInstance.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PartnerLinkInstance.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PartnerLinkInstance.java Thu Jul 27 14:51:14 2006
@@ -3,10 +3,10 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.o.OPartnerLink;
-import com.fs.utils.ObjectPrinter;
+import org.apache.ode.bpel.o.OPartnerLink;
+import org.apache.ode.utils.ObjectPrinter;
 
 import java.io.Serializable;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PropertyAliasEvaluationContext.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PropertyAliasEvaluationContext.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PropertyAliasEvaluationContext.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/PropertyAliasEvaluationContext.java Thu Jul 27 14:51:14 2006
@@ -3,13 +3,13 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.explang.EvaluationContext;
-import com.fs.pxe.bpel.o.*;
-import com.fs.pxe.bpel.o.OMessageVarType.Part;
-import com.fs.utils.DOMUtils;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.explang.EvaluationContext;
+import org.apache.ode.bpel.o.*;
+import org.apache.ode.bpel.o.OMessageVarType.Part;
+import org.apache.ode.utils.DOMUtils;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/REPLY.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/REPLY.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/REPLY.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/REPLY.java Thu Jul 27 14:51:14 2006
@@ -3,12 +3,12 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.o.OReply;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.runtime.channels.FaultData;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.o.OReply;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.runtime.channels.FaultData;
 
 import java.util.Iterator;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/RETHROW.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/RETHROW.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/RETHROW.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/RETHROW.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.runtime.channels.FaultData;
+import org.apache.ode.bpel.runtime.channels.FaultData;
 
 
 /**

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ResumeWork.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ResumeWork.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ResumeWork.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ResumeWork.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.utils.ObjectPrinter;
+import org.apache.ode.utils.ObjectPrinter;
 
 import java.io.Serializable;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SCOPE.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SCOPE.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SCOPE.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SCOPE.java Thu Jul 27 14:51:14 2006
@@ -3,14 +3,14 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import com.fs.jacob.ML;
 import com.fs.jacob.SynchChannel;
-import com.fs.pxe.bpel.evt.ScopeFaultEvent;
-import com.fs.pxe.bpel.evt.ScopeStartEvent;
-import com.fs.pxe.bpel.o.*;
-import com.fs.pxe.bpel.runtime.channels.*;
+import org.apache.ode.bpel.evt.ScopeFaultEvent;
+import org.apache.ode.bpel.evt.ScopeStartEvent;
+import org.apache.ode.bpel.o.*;
+import org.apache.ode.bpel.runtime.channels.*;
 
 import java.io.Serializable;
 import java.util.*;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SCOPEACT.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SCOPEACT.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SCOPEACT.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SCOPEACT.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.o.OScope;
+import org.apache.ode.bpel.o.OScope;
 
 /**
  * A scope activity. The scope activity creates a new scope frame and proceeeds

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SEQUENCE.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SEQUENCE.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SEQUENCE.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SEQUENCE.java Thu Jul 27 14:51:14 2006
@@ -3,13 +3,13 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import com.fs.jacob.SynchChannel;
-import com.fs.pxe.bpel.o.OActivity;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.o.OSequence;
-import com.fs.pxe.bpel.runtime.channels.*;
+import org.apache.ode.bpel.o.OActivity;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.o.OSequence;
+import org.apache.ode.bpel.runtime.channels.*;
 
 import java.util.*;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SWITCH.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SWITCH.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SWITCH.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SWITCH.java Thu Jul 27 14:51:14 2006
@@ -3,13 +3,13 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.explang.EvaluationContext;
-import com.fs.pxe.bpel.explang.EvaluationException;
-import com.fs.pxe.bpel.o.OSwitch;
-import com.fs.pxe.bpel.runtime.channels.FaultData;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.explang.EvaluationContext;
+import org.apache.ode.bpel.explang.EvaluationException;
+import org.apache.ode.bpel.o.OSwitch;
+import org.apache.ode.bpel.runtime.channels.FaultData;
 
 import java.util.Iterator;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ScopeFrame.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ScopeFrame.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ScopeFrame.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ScopeFrame.java Thu Jul 27 14:51:14 2006
@@ -3,12 +3,12 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.evt.ScopeEvent;
-import com.fs.pxe.bpel.o.OPartnerLink;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.runtime.channels.FaultData;
+import org.apache.ode.bpel.evt.ScopeEvent;
+import org.apache.ode.bpel.o.OPartnerLink;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.runtime.channels.FaultData;
 
 import java.io.Serializable;
 import java.util.ArrayList;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/Selector.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/Selector.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/Selector.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/Selector.java Thu Jul 27 14:51:14 2006
@@ -3,10 +3,10 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.common.CorrelationKey;
-import com.fs.utils.ObjectPrinter;
+import org.apache.ode.bpel.common.CorrelationKey;
+import org.apache.ode.utils.ObjectPrinter;
 
 import java.io.Serializable;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SystemException.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SystemException.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SystemException.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/SystemException.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 /**
  * Run-time exception indicating an infrastructure problem.

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/TERMINATE.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/TERMINATE.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/TERMINATE.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/TERMINATE.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 /**
  * Abstraction that performs the work of the <code>empty</code> activity.

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/THROW.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/THROW.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/THROW.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/THROW.java Thu Jul 27 14:51:14 2006
@@ -3,11 +3,11 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.o.OThrow;
-import com.fs.pxe.bpel.runtime.channels.FaultData;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.o.OThrow;
+import org.apache.ode.bpel.runtime.channels.FaultData;
 
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/TimerWork.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/TimerWork.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/TimerWork.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/TimerWork.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.utils.ObjectPrinter;
+import org.apache.ode.utils.ObjectPrinter;
 
 import java.io.Serializable;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/VariableInstance.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/VariableInstance.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/VariableInstance.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/VariableInstance.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.o.OScope;
+import org.apache.ode.bpel.o.OScope;
 
 import java.io.Serializable;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/WAIT.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/WAIT.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/WAIT.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/WAIT.java Thu Jul 27 14:51:14 2006
@@ -3,16 +3,16 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.explang.EvaluationContext;
-import com.fs.pxe.bpel.explang.EvaluationException;
-import com.fs.pxe.bpel.o.OWait;
-import com.fs.pxe.bpel.runtime.channels.TerminationML;
-import com.fs.pxe.bpel.runtime.channels.TimerResponseChannel;
-import com.fs.pxe.bpel.runtime.channels.TimerResponseML;
-import com.fs.utils.xsd.Duration;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.explang.EvaluationContext;
+import org.apache.ode.bpel.explang.EvaluationException;
+import org.apache.ode.bpel.o.OWait;
+import org.apache.ode.bpel.runtime.channels.TerminationML;
+import org.apache.ode.bpel.runtime.channels.TimerResponseChannel;
+import org.apache.ode.bpel.runtime.channels.TimerResponseML;
+import org.apache.ode.utils.xsd.Duration;
 
 import java.util.Calendar;
 import java.util.Date;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/WHILE.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/WHILE.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/WHILE.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/WHILE.java Thu Jul 27 14:51:14 2006
@@ -3,14 +3,14 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
 import com.fs.jacob.SynchChannel;
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.explang.EvaluationException;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.o.OWhile;
-import com.fs.pxe.bpel.runtime.channels.*;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.explang.EvaluationException;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.o.OWhile;
+import org.apache.ode.bpel.runtime.channels.*;
 
 import java.util.HashSet;
 import java.util.Set;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/breaks/ActivityBreakpointImpl.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/breaks/ActivityBreakpointImpl.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/breaks/ActivityBreakpointImpl.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/breaks/ActivityBreakpointImpl.java Thu Jul 27 14:51:14 2006
@@ -3,12 +3,12 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.breaks;
+package org.apache.ode.bpel.runtime.breaks;
 
-import com.fs.pxe.bpel.bdi.breaks.ActivityBreakpoint;
-import com.fs.pxe.bpel.evt.ActivityExecStartEvent;
-import com.fs.pxe.bpel.evt.BpelEvent;
-import com.fs.pxe.bpel.evt.ScopeCompletionEvent;
+import org.apache.ode.bpel.bdi.breaks.ActivityBreakpoint;
+import org.apache.ode.bpel.evt.ActivityExecStartEvent;
+import org.apache.ode.bpel.evt.BpelEvent;
+import org.apache.ode.bpel.evt.ScopeCompletionEvent;
 
 public class ActivityBreakpointImpl extends BreakpointImpl implements ActivityBreakpoint {
     private static final long serialVersionUID = -8717519287041871427L;
@@ -20,14 +20,14 @@
 	}
 
   /**
-	 * @see com.fs.pxe.bpel.bdi.breaks.ActivityBreakpoint#activityName()
+	 * @see org.apache.ode.bpel.bdi.breaks.ActivityBreakpoint#activityName()
 	 */
 	public String activityName() {
 		return _activityName;
 	}
 
   /**
-	 * @see com.fs.pxe.bpel.runtime.breaks.BreakpointImpl#checkBreak(com.fs.pxe.bpel.evt.BpelEvent)
+	 * @see org.apache.ode.bpel.runtime.breaks.BreakpointImpl#checkBreak(org.apache.ode.bpel.evt.BpelEvent)
 	 */
 	public boolean checkBreak(BpelEvent event) {
  		return isEnabled() 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/breaks/BreakpointImpl.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/breaks/BreakpointImpl.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/breaks/BreakpointImpl.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/breaks/BreakpointImpl.java Thu Jul 27 14:51:14 2006
@@ -3,10 +3,10 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.breaks;
+package org.apache.ode.bpel.runtime.breaks;
 
-import com.fs.pxe.bpel.bdi.breaks.Breakpoint;
-import com.fs.pxe.bpel.evt.BpelEvent;
+import org.apache.ode.bpel.bdi.breaks.Breakpoint;
+import org.apache.ode.bpel.evt.BpelEvent;
 
 import java.io.Serializable;
 
@@ -20,14 +20,14 @@
 	}
 
   /**
-	 * @see com.fs.pxe.bpel.bdi.breaks.Breakpoint#setEnabled(boolean)
+	 * @see org.apache.ode.bpel.bdi.breaks.Breakpoint#setEnabled(boolean)
 	 */
 	public void setEnabled(boolean enabled) {
 		_enabled = enabled;
 	}
 
   /**
-	 * @see com.fs.pxe.bpel.bdi.breaks.Breakpoint#isEnabled()
+	 * @see org.apache.ode.bpel.bdi.breaks.Breakpoint#isEnabled()
 	 */
 	public boolean isEnabled() {
 		return _enabled;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/Compensation.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/Compensation.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/Compensation.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/Compensation.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.channels;
+package org.apache.ode.bpel.runtime.channels;
 
 import com.fs.jacob.SynchChannel;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/EventHandlerControl.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/EventHandlerControl.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/EventHandlerControl.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/EventHandlerControl.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.channels;
+package org.apache.ode.bpel.runtime.channels;
 
 /**
  * Channel used to control processing of event handler activities.

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/FaultData.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/FaultData.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/FaultData.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/FaultData.java Thu Jul 27 14:51:14 2006
@@ -3,13 +3,13 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.channels;
+package org.apache.ode.bpel.runtime.channels;
 
-import com.fs.pxe.bpel.o.OBase;
-import com.fs.pxe.bpel.o.OElementVarType;
-import com.fs.pxe.bpel.o.OMessageVarType;
-import com.fs.pxe.bpel.o.OVarType;
-import com.fs.utils.SerializableElement;
+import org.apache.ode.bpel.o.OBase;
+import org.apache.ode.bpel.o.OElementVarType;
+import org.apache.ode.bpel.o.OMessageVarType;
+import org.apache.ode.bpel.o.OVarType;
+import org.apache.ode.utils.SerializableElement;
 import org.w3c.dom.Element;
 
 import javax.xml.namespace.QName;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/InvokeResponse.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/InvokeResponse.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/InvokeResponse.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/InvokeResponse.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.channels;
+package org.apache.ode.bpel.runtime.channels;
 
 /**
  * Response channel for pick requests.

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/LinkStatus.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/LinkStatus.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/LinkStatus.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/LinkStatus.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.channels;
+package org.apache.ode.bpel.runtime.channels;
 
 /**
  * @jacob.kind

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/ParentScope.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/ParentScope.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/ParentScope.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/ParentScope.java Thu Jul 27 14:51:14 2006
@@ -3,11 +3,11 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.channels;
+package org.apache.ode.bpel.runtime.channels;
 
 import com.fs.jacob.SynchChannel;
-import com.fs.pxe.bpel.o.OScope;
-import com.fs.pxe.bpel.runtime.CompensationHandler;
+import org.apache.ode.bpel.o.OScope;
+import org.apache.ode.bpel.runtime.CompensationHandler;
 
 import java.util.Set;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/PickResponse.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/PickResponse.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/PickResponse.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/PickResponse.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.channels;
+package org.apache.ode.bpel.runtime.channels;
 
 /**
  * Response channel for pick requests.

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/Termination.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/Termination.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/Termination.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/Termination.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.channels;
+package org.apache.ode.bpel.runtime.channels;
 
 /**
  * Channel used for parent-to-child scope communication. 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/TimerResponse.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/TimerResponse.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/TimerResponse.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/channels/TimerResponse.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.channels;
+package org.apache.ode.bpel.runtime.channels;
 
 /**
  * Channel for timer notification. 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/explang/konst/KonstExpressionLanguageRuntimeImpl.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/explang/konst/KonstExpressionLanguageRuntimeImpl.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/EventFilter.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/EventFilter.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.monitor;
+package org.apache.ode.bpel.runtime.monitor;
 
 import java.io.Serializable;
 

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/InstanceFilter.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/InstanceFilter.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/InstanceFilter.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/InstanceFilter.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.monitor;
+package org.apache.ode.bpel.runtime.monitor;
 
-import com.fs.pxe.bpel.common.CorrelationKey;
+import org.apache.ode.bpel.common.CorrelationKey;
 
 import java.io.Serializable;
 import java.util.Date;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/MonitorException.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/MonitorException.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/MonitorException.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/MonitorException.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.monitor;
+package org.apache.ode.bpel.runtime.monitor;
 
 /**
  * Error occured while monitoring process.

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/ProcessInstance.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/ProcessInstance.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/ProcessInstance.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/ProcessInstance.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.monitor;
+package org.apache.ode.bpel.runtime.monitor;
 
 import java.io.Serializable;
 import java.util.HashMap;

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/ProcessMonitor.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/ProcessMonitor.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/ProcessMonitor.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/ProcessMonitor.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.monitor;
+package org.apache.ode.bpel.runtime.monitor;
 
-import com.fs.pxe.bpel.o.OProcess;
+import org.apache.ode.bpel.o.OProcess;
 
 
 /**

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/msgs/Messages.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/msgs/Messages.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/msgs/Messages.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/msgs/Messages.java Thu Jul 27 14:51:14 2006
@@ -4,11 +4,11 @@
  *
  */
 
-package com.fs.pxe.bpel.runtime.msgs;
+package org.apache.ode.bpel.runtime.msgs;
 
 import javax.xml.namespace.QName;
 
-import com.fs.utils.msg.MessageBundle;
+import org.apache.ode.utils.msg.MessageBundle;
 
 /**
  * Message bundle for this package.
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessDDInitializer.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessDDInitializer.java Thu Jul 27 14:51:14 2006
@@ -1,19 +1,19 @@
-package com.fs.pxe.bpel.engine;
+package org.apache.ode.bpel.engine;
 
-import com.fs.utils.msg.MessageBundle;
-import com.fs.utils.Namespaces;
-import com.fs.utils.DOMUtils;
-import com.fs.pxe.bpel.o.OProcess;
-import com.fs.pxe.bpel.o.OPartnerLink;
-import com.fs.pxe.bpel.dao.ProcessDAO;
-import com.fs.pxe.bpel.dao.PartnerLinkDAO;
-import com.fs.pxe.bpel.iapi.BpelEngineException;
-import com.fs.pxe.bpel.iapi.EndpointReference;
-import com.fs.pxe.bpel.iapi.EndpointReferenceContext;
-import com.fs.pxe.bom.wsdl.Definition4BPEL;
-import com.fs.pxe.bpel.dd2.TDeployment;
-import com.fs.pxe.bpel.dd2.TInvoke;
-import com.fs.pxe.bpel.dd2.TProvide;
+import org.apache.ode.utils.msg.MessageBundle;
+import org.apache.ode.utils.Namespaces;
+import org.apache.ode.utils.DOMUtils;
+import org.apache.ode.bpel.o.OProcess;
+import org.apache.ode.bpel.o.OPartnerLink;
+import org.apache.ode.bpel.dao.ProcessDAO;
+import org.apache.ode.bpel.dao.PartnerLinkDAO;
+import org.apache.ode.bpel.iapi.BpelEngineException;
+import org.apache.ode.bpel.iapi.EndpointReference;
+import org.apache.ode.bpel.iapi.EndpointReferenceContext;
+import org.apache.ode.bom.wsdl.Definition4BPEL;
+import org.apache.ode.bpel.dd2.TDeployment;
+import org.apache.ode.bpel.dd2.TInvoke;
+import org.apache.ode.bpel.dd2.TProvide;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.w3c.dom.Element;
@@ -28,7 +28,7 @@
 
 /**
  * Extracts and treats process deployment descriptors. The descriptor interacts
  * with the process deployment either by modifying the {@link com.fs.pxe.bpel.dao.ProcessDAO}.
  */
 class ProcessDDInitializer {
 
@@ -28,7 +28,7 @@
 /**
  * Extracts and treats process deployment descriptors. The descriptor interacts
- * with the process deployment either by modifying the {@link com.fs.pxe.bpel.dao.ProcessDAO}.
+ * with the process deployment either by modifying the {@link org.apache.ode.bpel.dao.ProcessDAO}.
  */
 class ProcessDDInitializer {

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessInitializer.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessInitializer.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessStatusConverter.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ProcessStatusConverter.java Thu Jul 27 14:51:14 2006
@@ -1,14 +1,14 @@
-package com.fs.pxe.bpel.engine;
+package org.apache.ode.bpel.engine;
 
 import java.util.BitSet;
 import java.util.HashMap;
 import java.util.Map;
 
-import com.fs.pxe.bpel.common.ProcessState;
-import com.fs.pxe.bpel.dao.ScopeStateEnum;
-import com.fs.pxe.bpel.pmapi.ProcessingException;
-import com.fs.pxe.bpel.pmapi.TInstanceStatus;
-import com.fs.pxe.bpel.pmapi.TScopeStatus;
+import org.apache.ode.bpel.common.ProcessState;
+import org.apache.ode.bpel.dao.ScopeStateEnum;
+import org.apache.ode.bpel.pmapi.ProcessingException;
+import org.apache.ode.bpel.pmapi.TInstanceStatus;
+import org.apache.ode.bpel.pmapi.TScopeStatus;
 
 /**
  * Class for converting status codes from external (PMAPI) to internal (DAO) representation.
@@ -16,7 +16,7 @@
 class ProcessStatusConverter {
 
   /** 
    * A mapping from the interface status codes, to the internal PXE status codes.
    */
   private final Map<TInstanceStatus.Enum, BitSet> __interfaceStatusCodeToInternalStatusCodeMap =
   	new HashMap<TInstanceStatus.Enum,BitSet>();
@@ -16,7 +16,7 @@
 
   /** 
-   * A mapping from the interface status codes, to the internal PXE status codes.
+   * A mapping from the interface status codes, to the internal ODE status codes.
    */
   private final Map<TInstanceStatus.Enum, BitSet> __interfaceStatusCodeToInternalStatusCodeMap =

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ReplacementMapImpl.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/engine/ReplacementMapImpl.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ExprEvaluationContextImpl.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ExprEvaluationContextImpl.java Thu Jul 27 14:51:14 2006
@@ -3,12 +3,12 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime;
+package org.apache.ode.bpel.runtime;
 
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.explang.EvaluationContext;
-import com.fs.pxe.bpel.o.*;
-import com.fs.pxe.bpel.o.OMessageVarType.Part;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.explang.EvaluationContext;
+import org.apache.ode.bpel.o.*;
+import org.apache.ode.bpel.o.OMessageVarType.Part;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.w3c.dom.Element;
@@ -18,7 +18,7 @@
 
 /**
  * The context in which BPEL expressions are evaluated. This class is handed of
  * the {@link com.fs.pxe.bpel.o.OExpression} instances to provide access to
  * variables, link statuses, and the like.
  */
 public class ExprEvaluationContextImpl implements EvaluationContext {
@@ -69,7 +69,7 @@
     try {
       return _native.getExpLangRuntime().evaluateNode(expr,
           new ExprEvaluationContextImpl(_scopeInstance, _native, root));
-    } catch (com.fs.pxe.bpel.explang.EvaluationException e) {
+    } catch (org.apache.ode.bpel.explang.EvaluationException e) {
       throw new InvalidProcessException("Expression Failed: " + expr, e);
     }
   }
@@ -18,7 +18,7 @@
 /**
  * The context in which BPEL expressions are evaluated. This class is handed of
- * the {@link com.fs.pxe.bpel.o.OExpression} instances to provide access to
+ * the {@link org.apache.ode.bpel.o.OExpression} instances to provide access to
  * variables, link statuses, and the like.
  */

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ExpressionLanguageRuntimeRegistry.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/ExpressionLanguageRuntimeRegistry.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/explang/konst/KonstExpressionLanguageRuntimeImpl.java (original)
+++ incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/explang/konst/KonstExpressionLanguageRuntimeImpl.java Thu Jul 27 14:51:14 2006
@@ -3,13 +3,13 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.bpel.runtime.explang.konst;
+package org.apache.ode.bpel.runtime.explang.konst;
 
-import com.fs.pxe.bpel.common.FaultException;
-import com.fs.pxe.bpel.explang.*;
-import com.fs.pxe.bpel.o.OConstantExpression;
-import com.fs.pxe.bpel.o.OExpression;
-import com.fs.utils.xsd.Duration;
+import org.apache.ode.bpel.common.FaultException;
+import org.apache.ode.bpel.explang.*;
+import org.apache.ode.bpel.o.OConstantExpression;
+import org.apache.ode.bpel.o.OExpression;
+import org.apache.ode.utils.xsd.Duration;
 import org.w3c.dom.Node;
 
 import java.util.Calendar;
@@ -17,7 +17,7 @@
 import java.util.Map;
 
 /**
  * An implementation of the {@link com.fs.pxe.bpel.explang.ExpressionLanguageRuntime} interface
  * for constant expressions.
  */
 public class KonstExpressionLanguageRuntimeImpl implements ExpressionLanguageRuntime {
@@ -17,7 +17,7 @@
 
 /**
- * An implementation of the {@link com.fs.pxe.bpel.explang.ExpressionLanguageRuntime} interface
+ * An implementation of the {@link org.apache.ode.bpel.explang.ExpressionLanguageRuntime} interface
  * for constant expressions.
  */

Modified: incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/EventFilter.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/bpel-runtime/src/main/java/org/apache/ode/bpel/runtime/monitor/EventFilter.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================